==> lovelaice-0.3.7.tar.gz: lovelaice-0.3.7/argo/CONTRIBUTING.md <==
# Contributing to ARGO

Thank you for your interest in contributing to **ARGO**! We welcome contributions of all kinds, including code, documentation, bug reports, feature requests, and community support.

## How to Contribute

- **Find an Issue:** Look for issues labeled `good first issue` or `help wanted` to get started. You do not need to be assigned to an issue before submitting a pull request.
- **Open Discussion:** If you have an idea for a new feature or a significant change, please open a GitHub issue first to discuss your proposal with the maintainers.
- **Documentation:** If you find something missing or unclear in the documentation, please submit a pull request to improve it!

## Development Workflow

1. **Fork the repository** and clone it locally.
2. **Create a new branch** for your feature or bugfix.
3. **Write tests** for your changes. PRs without tests are unlikely to be accepted.
4. **Follow code style guidelines** (PEP8 for Python).
5. **Submit a pull request** with a clear description of your changes and reference any related issues.

## Committing

- Write clear, concise commit messages.
- Group related changes into a single commit.

## Dependencies

Before adding a new dependency, ensure that:
- There is a strong use case for it.
- It has an acceptable license (e.g., MIT, Apache 2.0).
- It is actively maintained.
- It has no known security issues[1][5].

## Review Process

- Anyone can review a pull request and leave comments or suggestions.
- Maintainers will review and merge pull requests that meet project standards.
- Larger features may require a design document or proposal before implementation[6].
- If an issue is a user error, relabel it as `type/support` instead of `type/bug`.
- Issues needing more information should be labeled `problem/more information needed`. If there is no response, they may be marked as stale and closed automatically[1].

## Community

- Join our discussions in GitHub Issues and Discussions.
- Be respectful and follow our Code of Conduct.

## Code of Conduct

By participating in this project, you agree to abide by our [Code of Conduct](CODE_OF_CONDUCT.md).

We appreciate your help in making ARGO better! If you have any questions, please open an issue or join the conversation.

==> lovelaice-0.4.2.tar.gz: lovelaice-0.4.2/argo/CONTRIBUTING.md <==
# Contributing to ARGO

Thank you for your interest in contributing to **ARGO**! We welcome contributions of all kinds, including code, documentation, bug reports, feature requests, and community support.

## How to Contribute

- **Find an Issue:** Look for issues labeled `good first issue` or `help wanted` to get started. You do not need to be assigned to an issue before submitting a pull request.
- **Open Discussion:** If you have an idea for a new feature or a significant change, please open a GitHub issue first to discuss your proposal with the maintainers.
- **Documentation:** If you find something missing or unclear in the documentation, please submit a pull request to improve it!

## Development Workflow

1. **Fork the repository** and clone it locally.
2. **Create a new branch** for your feature or bugfix.
3. **Write tests** for your changes. PRs without tests are unlikely to be accepted.
4. **Follow code style guidelines** using the black Python formatter.
5. **Submit a pull request** with a clear description of your changes and reference any related issues.

## Committing

- Write clear, concise commit messages.
- Group related changes into a single commit.

## Dependencies

Before adding a new dependency, ensure that:

- There is a strong use case for it.
- It has an acceptable license (e.g., MIT, Apache 2.0).
- It is actively maintained.
- It has no known security issues.

## Review Process

- Anyone can review a pull request and leave comments or suggestions.
- Maintainers will review and merge pull requests that meet project standards.
- Larger features may require a design document or proposal before implementation.
- If an issue is a user error, relabel it as `type/support` instead of `type/bug`.
- Issues needing more information should be labeled `problem/more information needed`. If there is no response, they may be marked as stale and closed automatically.

## Community

- Join our discussions in GitHub Issues and Discussions.
- Be respectful and follow our Code of Conduct.

## Code of Conduct

By participating in this project, you agree to abide by our [Code of Conduct](CODE_OF_CONDUCT.md).

We appreciate your help in making ARGO better! If you have any questions, please open an issue or join the conversation.
